dnl @synopsis AC_FC_BLAS([ACTION-IF-FOUND[, ACTION-IF-NOT-FOUND]])
dnl
dnl This macro looks for a library that implements the BLAS
dnl linear-algebra interface (see http://www.netlib.org/blas/).
dnl On success, it sets the BLAS_LIBS output variable to
dnl hold the requisite library linkages.
dnl
dnl To link with BLAS, you should link with:
dnl
dnl 	$BLAS_LIBS $LIBS
dnl
dnl in that order.
dnl
dnl Many libraries are searched for, from ATLAS to CXML to ESSL.
dnl The user may also use --with-blas=<lib> in order to use some
dnl specific BLAS library <lib>.  In order to link successfully,
dnl however, be aware that you will probably need to use the same
dnl Fortran compiler (which can be set via the F77 env. var.) as
dnl was used to compile the BLAS library.
dnl
dnl ACTION-IF-FOUND is a list of shell commands to run if a BLAS
dnl library is found, and ACTION-IF-NOT-FOUND is a list of commands
dnl to run it if it is not found.  If ACTION-IF-FOUND is not specified,
dnl the default action will define HAVE_BLAS.
dnl
dnl This macro requires autoconf 2.50 or later.
dnl
dnl @version $Id: ac_fc_blas.m4,v 1.1.1.1 2005/10/26 09:58:30 dumas Exp $
dnl @author Steven G. Johnson <stevenj@alum.mit.edu>
dnl
AC_DEFUN([AC_FC_BLAS], [
AC_PREREQ(2.50)
ac_fc_blas_ok=no

AC_ARG_WITH(blas,
	[AC_HELP_STRING([--with-blas=<lib>], [use BLAS library <lib>])])
case $with_blas in
	yes | "") ;;
	no) ac_fc_blas_ok=disable ;;
	-* | */* | *.a | *.so | *.so.* | *.o) BLAS_LIBS="$with_blas" ;;
	*) BLAS_LIBS="-l$with_blas" ;;
esac

ac_fc_blas_save_LIBS="$LIBS"
LIBS="$LIBS $FLIBS"

# First, check BLAS_LIBS environment variable
if test $ac_fc_blas_ok = no; then
if test "x$BLAS_LIBS" != x; then
	save_LIBS="$LIBS"; LIBS="$BLAS_LIBS $LIBS"
	AC_MSG_CHECKING([for sgemm in $BLAS_LIBS])
	AC_TRY_LINK_FUNC(sgemm, [ac_fc_blas_ok=yes], [BLAS_LIBS=""])
	AC_MSG_RESULT($ac_fc_blas_ok)
	LIBS="$save_LIBS"
fi
fi

# BLAS linked to by default?  (happens on some supercomputers)
if test $ac_fc_blas_ok = no; then
	save_LIBS="$LIBS"; LIBS="$LIBS"
dnl	AC_CHECK_FUNC($sgemm, [ac_fc_blas_ok=yes])
	AC_MSG_CHECKING([for sgemm linked by default])
	AC_TRY_LINK_FUNC(sgemm, [ac_fc_blas_ok=yes])
	AC_MSG_RESULT($ac_fc_blas_ok)
	LIBS="$save_LIBS"
fi

# BLAS in ATLAS library? (http://math-atlas.sourceforge.net/)
if test $ac_fc_blas_ok = no; then
	AC_CHECK_LIB(f77blas, sgemm,
		[ac_fc_blas_ok=yes
		 BLAS_LIBS="-lf77blas -latlas"],
		[], [-latlas])
fi

# BLAS in PhiPACK libraries? (requires generic BLAS lib, too)
if test $ac_fc_blas_ok = no; then
	AC_CHECK_LIB(blas, sgemm,
		[AC_CHECK_LIB(dgemm, dgemm,
		[AC_CHECK_LIB(sgemm, sgemm,
			[ac_fc_blas_ok=yes; BLAS_LIBS="-lsgemm -ldgemm -lblas"],
			[], [-lblas])],
			[], [-lblas])])
fi

# BLAS in Alpha CXML library?
if test $ac_fc_blas_ok = no; then
	AC_CHECK_LIB(cxml, sgemm, [ac_fc_blas_ok=yes;BLAS_LIBS="-lcxml"])
fi

# BLAS in Alpha DXML library? (now called CXML, see above)
if test $ac_fc_blas_ok = no; then
	AC_CHECK_LIB(dxml, sgemm, [ac_fc_blas_ok=yes;BLAS_LIBS="-ldxml"])
fi

# BLAS in Sun Performance library?
if test $ac_fc_blas_ok = no; then
	if test "x$GCC" != xyes; then # only works with Sun CC
		AC_CHECK_LIB(sunmath, acosp,
			[AC_CHECK_LIB(sunperf, sgemm,
        			[BLAS_LIBS="-xlic_lib=sunperf -lsunmath"
                                 ac_fc_blas_ok=yes],[],[-lsunmath])])
	fi
fi

# BLAS in SCSL library?  (SGI/Cray Scientific Library)
if test $ac_fc_blas_ok = no; then
	AC_CHECK_LIB(scs, sgemm, [ac_fc_blas_ok=yes; BLAS_LIBS="-lscs"])
fi

# BLAS in SGIMATH library?
if test $ac_fc_blas_ok = no; then
	AC_CHECK_LIB(complib.sgimath, sgemm,
		     [ac_fc_blas_ok=yes; BLAS_LIBS="-lcomplib.sgimath"])
fi

# BLAS in IBM ESSL library? (requires generic BLAS lib, too)
if test $ac_fc_blas_ok = no; then
	AC_CHECK_LIB(blas, sgemm,
		[AC_CHECK_LIB(essl, sgemm,
			[ac_fc_blas_ok=yes; BLAS_LIBS="-lessl -lblas"],
			[], [-lblas])])
fi

# Generic BLAS library?
if test $ac_fc_blas_ok = no; then
	AC_CHECK_LIB(blas, sgemm, [ac_fc_blas_ok=yes; BLAS_LIBS="-lblas"])
fi

AC_SUBST(BLAS_LIBS)

LIBS="$ac_fc_blas_save_LIBS"

# Finally, execute ACTION-IF-FOUND/ACTION-IF-NOT-FOUND:
if test x"$ac_fc_blas_ok" = xyes; then
        ifelse([$1],,AC_DEFINE(HAVE_BLAS,1,[Define if you have a BLAS library.]),[$1])
        :
else
        ac_fc_blas_ok=no
        $2
fi
])dnl ACX_BLAS
